@@ -101,6 +101,21 @@ public:
     virtual void invtrans_vordiv2wind( const Field& spvor, const Field& spdiv, Field& gpwind,
                                        const eckit::Configuration& = util::NoConfig() ) const override;
 
+    virtual void invtrans_adj( const Field& gpfield, Field& spfield,
+                               const eckit::Configuration& = util::NoConfig() ) const override;
+
+    virtual void invtrans_adj( const FieldSet& gpfields, FieldSet& spfields,
+                               const eckit::Configuration& = util::NoConfig() ) const override;
+
+    virtual void invtrans_grad_adj( const Field& gradfield, Field& spfield,
+                                    const eckit::Configuration& = util::NoConfig() ) const override;
+
+    virtual void invtrans_grad_adj( const FieldSet& spfields, FieldSet& gradfields,
+                                    const eckit::Configuration& = util::NoConfig() ) const override;
+
+    virtual void invtrans_vordiv2wind_adj( const Field& gpwind, Field& spvor, Field& spdiv,
+                                           const eckit::Configuration& = util::NoConfig() ) const override;
+
     // -- IFS style API --
 
     virtual void invtrans( const int nb_scalar_fields, const double scalar_spectra[], const int nb_vordiv_fields,
@@ -114,6 +129,17 @@ public:
                            const double divergence_spectra[], double gp_fields[],
                            const eckit::Configuration& = util::NoConfig() ) const override;
 
+    virtual void invtrans_adj( const int nb_scalar_fields, const double gp_fields[], const int nb_vordiv_fields,
+                               double vorticity_spectra[], double divergence_spectra[], double scalar_spectra[],
+                               const eckit::Configuration& = util::NoConfig() ) const override;
+
+    virtual void invtrans_adj( const int nb_scalar_fields, const double gp_fields[], double scalar_spectra[],
+                               const eckit::Configuration& = util::NoConfig() ) const override;
+
+    virtual void invtrans_adj( const int nb_vordiv_fields, const double gp_fields[], double vorticity_spectra[],
+                               double divergence_spectra[],
+                               const eckit::Configuration& = util::NoConfig() ) const override;
+
     // -- NOT SUPPORTED -- //
 
     virtual void dirtrans( const Field& gpfield, Field& spfield,
